@@ -6,4 +6,8 @@ void BinomLogitMixed(int *Y, double **X, double ***Z, int *grp, double *beta,
 		     int n_random, int n_grp, double *beta0, double **A0, int tau0,
 		     double **T0, double **tune_fixed, double *tune_random, int n_gen,
 		     int *acc_fixed, int *acc_random);
-		     
+
+void bNormalReg(double *Y, double **X, double *beta, double *sig2, 
+		int n_samp, int n_cov, int addprior, int pbeta, 
+		double *beta0, double **A0, int psig2, double s0, 
+		int nu0, int sig2fixed);
